@@ -171,14 +171,14 @@ pref("mail.file_attach_binary",             false);
 pref("mail.show_headers",                   1); // some
 pref("mail.pane_config",                    0);
 pref("mail.addr_book.mapit_url.format", "chrome://messenger-region/locale/region.properties");
-//@line 175 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/mailnews/mailnews.js"
+//@line 175 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/mailnews/mailnews.js"
 pref("mailnews.start_page.url", "chrome://messenger-region/locale/region.properties");
 pref("mail.addr_book.im.onlineCheckAllowed", false);
 pref("messenger.throbber.url","chrome://messenger-region/locale/region.properties");
 pref("compose.throbber.url","chrome://messenger-region/locale/region.properties");
 pref("addressbook.throbber.url","chrome://messenger-region/locale/region.properties");
 pref("mail.accountwizard.deferstorage", false);
-//@line 182 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/mailnews/mailnews.js"
+//@line 182 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/mailnews/mailnews.js"
 
 // the format for "mail.addr_book.quicksearchquery.format" is:
 // @V == the escaped value typed in the quick search bar in the addressbook
@@ -510,7 +510,7 @@ pref("mail.server.default.spamActionTargetFolder","");
 pref("mail.server.default.useWhiteList",true);
 pref("mail.server.default.whiteListAbURI","moz-abmdbdirectory://abook.mab");  // the Personal addressbook.
 pref("mail.server.default.useServerFilter", false);
-pref("mail.server.default.serverFilterName", "SpamAssasin");
+pref("mail.server.default.serverFilterName", "SpamAssassin");
 pref("mail.server.default.serverFilterTrustFlags", 1); // 1 == trust positives, 2 == trust negatives, 3 == trust both
 pref("mail.server.default.purgeSpam",false);
 pref("mail.server.default.purgeSpamInterval",14); // 14 days
@@ -729,9 +729,9 @@ pref("mail.standalone", false);
 // the users last used preference.
 pref("mailnews.import.text.skipfirstrecord", true);
 
-//@line 739 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/mailnews/mailnews.js"
+//@line 739 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/mailnews/mailnews.js"
 
-//@line 742 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/mailnews/mailnews.js"
+//@line 742 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/mailnews/mailnews.js"
 pref("mail.empty_trash", false);
 
 pref("mail.check_new_mail", true);
@@ -748,5 +748,5 @@ pref("news.show_first_unread", false);
 pref("news.sash_geometry", "");
 pref("mail.signature_date", 0);
 
-//@line 761 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/mailnews/mailnews.js"
+//@line 761 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/mailnews/mailnews.js"
 
