@@ -109,7 +109,7 @@ pref("browser.chrome.image_icons.max_size", 1024);
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 113 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 113 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -117,7 +117,7 @@ pref("accessibility.warn_on_browsewithcaret", true);
 // unless accessibility.tabfocus is set by the user.
 pref("accessibility.tabfocus", 7);
 pref("accessibility.tabfocus_applies_to_xul", false);
-//@line 124 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 124 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -487,7 +487,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 496 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 496 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -578,6 +578,11 @@ pref("network.http.pipelining.maxrequests" , 4);
 
 // </http>
 
+// If false, remote JAR files that are served with a content type other than
+// application/java-archive or application/x-jar will not be opened
+// by the jar channel.
+pref("network.jar.open-unsafe-types", false);
+
 // This preference controls whether or not internationalized domain names (IDN)
 // are handled.  IDN requires a nsIIDNService implementation.
 pref("network.enableIDN", true);
@@ -603,10 +608,12 @@ pref("network.IDN.whitelist.cl", true);
 pref("network.IDN.whitelist.cn", true);
 pref("network.IDN.whitelist.de", true);
 pref("network.IDN.whitelist.dk", true);
+pref("network.IDN.whitelist.es", true);
 pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
 pref("network.IDN.whitelist.io", true);
+pref("network.IDN.whitelist.ir", true);
 pref("network.IDN.whitelist.is", true);
 pref("network.IDN.whitelist.jp", true);
 pref("network.IDN.whitelist.kr", true);
@@ -685,7 +692,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 699 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 706 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -833,7 +840,7 @@ pref("mousewheel.withmetakey.sysnumlines",true);
 
 // on platforms where scroll messages differ between horizontal scroll
 // and back/forward button events we can activate them by default
-//@line 881 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 888 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 // disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
@@ -850,7 +857,7 @@ pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withmetakey.action",2);
 pref("mousewheel.horizscroll.withmetakey.numlines",-1);
 pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
-//@line 898 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 905 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -993,15 +1000,15 @@ pref("dom.max_script_run_time", 10);
 
 pref("svg.enabled", true);
 
-//@line 1371 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 1378 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1563 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 1570 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1752 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 1759 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1841 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 1848 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1844 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 1851 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1074,7 +1081,7 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-//@line 1977 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 1984 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 pref("font.name.serif.el", "misc-fixed-iso8859-7");
 pref("font.name.sans-serif.el", "misc-fixed-iso8859-7");
 pref("font.name.monospace.el", "misc-fixed-iso8859-7");
@@ -1132,7 +1139,7 @@ pref("font.name.sans-serif.zh-HK", "-arphic-Ming for ISO10646-big5hkscs-0");
 pref("font.name.monospace.zh-HK", "-arphic-Ming for ISO10646-big5hkscs-0");
 
 // zh-TW
-//@line 2036 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 2043 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
@@ -1350,15 +1357,15 @@ pref("print.postscript.nativefont.zh-CN",          "");
 pref("print.postscript.nativefont.zh-TW",          "");
 pref("print.postscript.nativefont.zh-HK",          "");
 
-//@line 2256 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 2263 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2324 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 2331 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2350 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 2357 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2370 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 2377 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2378 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 2385 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2380 "/home/hafi/seam/release/gtk1/1.1.6/mozilla/modules/libpref/src/init/all.js"
+//@line 2387 "/home/hafi/seam/release/gtk1/1.1.9/mozilla/modules/libpref/src/init/all.js"
 pref("network.gnomevfs.supported-protocols", "smb:,sftp:");
